const assert = require('chai').assert;
const node_nudb = require('../lib');

const argv = require('yargs').usage('Usage: $0 [options]')
    .alias('h', 'host')
    .describe('h', 'Host')
    .alias('p', 'port')
    .describe('p', 'Port')
    .alias('d', 'db')
    .describe('d', 'DB name')
    .demandOption(['host', 'port', 'db'])
    .help('H')
    .alias('H', 'help')
    .argv;

let nudb = new node_nudb.Nudb();
nudb.connect(argv.host, argv.port, argv.db);

describe('getDBInfo test', () => {
    it('getDBInfo', async (done) => {

        try {
            let dbInfo = await nudb.getDBInfo(argv.db);
            assert.isUndefined(dbInfo.error);
            assert.isDefined(dbInfo.result);
            assert.isObject(dbInfo.result);
        } catch(err) {
            console.log(err);
        }
        done();
    });
});

describe('CRUD test', () => {
    it('Search', async (done) => {
        try {
            let query = {
                db: argv.db,
                q: '柯文哲',
                p: 1,
                ps: 5,
                out: 'json'
            };
            let result = await nudb.search(query);
            assert.isUndefined(result.error);
            assert.isDefined(result.result);
            assert.isObject(result.result);
        } catch(err) {
            console.log(err);
        }
        done();
    });

    it('rget', async (done) => {
        try {
            let result = await nudb.rget(1);
            console.log(result);
            assert.isUndefined(result.error);
            assert.isDefined(result.result);
            assert.isObject(result.result);
        } catch(err) {
            console.log(err);
        }
        done();
    });
});